/*
 * linux/arch/arm/mach-omap2/board-am3517somiq.c
 *
 * Copyright (C) 2012 MENTOREL Limited
 * Author: Maxim Podbereznyy <support@mentorel.com>
 *
 * Based on mach-omap2/board-omap3evm.c
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as  published by the
 * Free Software Foundation version 2.
 *
 * This program is distributed "as is" WITHOUT ANY WARRANTY of any kind,
 * whether express or implied; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 */

#include <linux/kernel.h>
#include <linux/init.h>
#include <linux/clk.h>
#include <linux/platform_device.h>
#include <linux/gpio.h>
#include <linux/can/platform/ti_hecc.h>
#include <linux/davinci_emac.h>
#include <linux/irq.h>
#include <linux/input.h>
#include <linux/mmc/host.h>
#include <linux/mtd/physmap.h>
#include <linux/mtd/mtd.h>
#include <linux/mtd/partitions.h>
#include <linux/mtd/nand.h>
#include <linux/regulator/machine.h>
#include <linux/i2c/tps65910.h>

#include <mach/hardware.h>
#include <mach/am35xx.h>
#include <asm/mach-types.h>
#include <asm/mach/arch.h>
#include <asm/mach/map.h>

#include <plat/board.h>
#include <plat/common.h>
#include <plat/usb.h>
#include <plat/display.h>
#include <plat/gpmc.h>
#include <plat/nand.h>

#include "mux.h"
#include "control.h"
#include "hsmmc.h"
#include "board-flash.h"

#define AM35XX_EVM_MDIO_FREQUENCY	(1000000)

#define NAND_BLOCK_SIZE        SZ_128K

#ifdef CONFIG_MTD_NAND_OMAP2
static struct mtd_partition am3517somiq_nand_partitions[] = {
/* All the partition sizes are listed in terms of NAND block size */
	{
		.name           = "xloader-nand",
		.offset         = 0,
		.size           = 4*(SZ_128K),
		.mask_flags     = MTD_WRITEABLE
	},
	{
		.name           = "uboot-nand",
		.offset         = MTDPART_OFS_APPEND,
		.size           = 14*(SZ_128K),
		.mask_flags     = MTD_WRITEABLE
	},
	{
		.name           = "params-nand",
		.offset         = MTDPART_OFS_APPEND,
		.size           = 2*(SZ_128K)
	},
	{
		.name           = "linux-nand",
		.offset         = MTDPART_OFS_APPEND,
		.size           = 40*(SZ_128K)
	},
	{
		.name           = "jffs2-nand",
		.size           = MTDPART_SIZ_FULL,
		.offset         = MTDPART_OFS_APPEND,
	},
};
#endif

static struct mdio_platform_data am3517somiq_mdio_pdata = {
	.bus_freq	= AM35XX_EVM_MDIO_FREQUENCY,
};

static struct resource am3517_mdio_resources[] = {
	{
		.start  = AM35XX_IPSS_EMAC_BASE + AM35XX_EMAC_MDIO_OFFSET,
		.end    = AM35XX_IPSS_EMAC_BASE + AM35XX_EMAC_MDIO_OFFSET +
			  SZ_4K - 1,
		.flags  = IORESOURCE_MEM,
	},
};

static struct platform_device am3517_mdio_device = {
	.name		= "davinci_mdio",
	.id		= -1,
	.num_resources	= ARRAY_SIZE(am3517_mdio_resources),
	.resource	= am3517_mdio_resources,
	.dev.platform_data = &am3517somiq_mdio_pdata,
};

static struct emac_platform_data am3517somiq_emac_pdata = {
	.rmii_en	= 1,
};

static int __init eth_addr_setup(char *str)
{
	int i;

	if (str == NULL)
		return 0;

	for (i = 0; i <  ETH_ALEN; i++) {
		am3517somiq_emac_pdata.mac_addr[i] = 
			simple_strtol(&str[i*3], (char **)NULL, 16);
	}
	return 1;
}

/* Get MAC address from kernel boot parameter eth=AA:BB:CC:DD:EE:FF */
__setup("eth=", eth_addr_setup);

static struct resource am3517_emac_resources[] = {
	{
		.start  = AM35XX_IPSS_EMAC_BASE,
		.end    = AM35XX_IPSS_EMAC_BASE + 0x2FFFF,
		.flags  = IORESOURCE_MEM,
	},
	{
		.start  = INT_35XX_EMAC_C0_RXTHRESH_IRQ,
		.end    = INT_35XX_EMAC_C0_RXTHRESH_IRQ,
		.flags  = IORESOURCE_IRQ,
	},
	{
		.start  = INT_35XX_EMAC_C0_RX_PULSE_IRQ,
		.end    = INT_35XX_EMAC_C0_RX_PULSE_IRQ,
		.flags  = IORESOURCE_IRQ,
	},
	{
		.start  = INT_35XX_EMAC_C0_TX_PULSE_IRQ,
		.end    = INT_35XX_EMAC_C0_TX_PULSE_IRQ,
		.flags  = IORESOURCE_IRQ,
	},
	{
		.start  = INT_35XX_EMAC_C0_MISC_PULSE_IRQ,
		.end    = INT_35XX_EMAC_C0_MISC_PULSE_IRQ,
		.flags  = IORESOURCE_IRQ,
	},
};

static struct platform_device am3517_emac_device = {
	.name		= "davinci_emac",
	.id		= -1,
	.num_resources	= ARRAY_SIZE(am3517_emac_resources),
	.resource	= am3517_emac_resources,
};

static void am3517_enable_ethernet_int(void)
{
	u32 regval;

	regval = omap_ctrl_readl(AM35XX_CONTROL_LVL_INTR_CLEAR);
	regval = (regval | AM35XX_CPGMAC_C0_RX_PULSE_CLR |
		AM35XX_CPGMAC_C0_TX_PULSE_CLR |
		AM35XX_CPGMAC_C0_MISC_PULSE_CLR |
		AM35XX_CPGMAC_C0_RX_THRESH_CLR);
	omap_ctrl_writel(regval, AM35XX_CONTROL_LVL_INTR_CLEAR);
	regval = omap_ctrl_readl(AM35XX_CONTROL_LVL_INTR_CLEAR);
}

static void am3517_disable_ethernet_int(void)
{
	u32 regval;

	regval = omap_ctrl_readl(AM35XX_CONTROL_LVL_INTR_CLEAR);
	regval = (regval | AM35XX_CPGMAC_C0_RX_PULSE_CLR |
		AM35XX_CPGMAC_C0_TX_PULSE_CLR);
	omap_ctrl_writel(regval, AM35XX_CONTROL_LVL_INTR_CLEAR);
	regval = omap_ctrl_readl(AM35XX_CONTROL_LVL_INTR_CLEAR);
}

static void am3517somiq_ethernet_init(struct emac_platform_data *pdata)
{
	u32 regval;

	pdata->ctrl_reg_offset		= AM35XX_EMAC_CNTRL_OFFSET;
	pdata->ctrl_mod_reg_offset	= AM35XX_EMAC_CNTRL_MOD_OFFSET;
	pdata->ctrl_ram_offset		= AM35XX_EMAC_CNTRL_RAM_OFFSET;
	pdata->ctrl_ram_size		= AM35XX_EMAC_CNTRL_RAM_SIZE;
	pdata->version			= EMAC_VERSION_2;
	pdata->hw_ram_addr		= AM35XX_EMAC_HW_RAM_ADDR;
	pdata->interrupt_enable		= am3517_enable_ethernet_int;
	pdata->interrupt_disable	= am3517_disable_ethernet_int;
	am3517_emac_device.dev.platform_data	= pdata;
	platform_device_register(&am3517_mdio_device);
	platform_device_register(&am3517_emac_device);
	clk_add_alias(NULL, dev_name(&am3517_mdio_device.dev),
		      NULL, &am3517_emac_device.dev);

	regval = omap_ctrl_readl(AM35XX_CONTROL_IP_SW_RESET);
	regval = regval & (~(AM35XX_CPGMACSS_SW_RST));
	omap_ctrl_writel(regval, AM35XX_CONTROL_IP_SW_RESET);
	regval = omap_ctrl_readl(AM35XX_CONTROL_IP_SW_RESET);

	return ;
}

#if defined(CONFIG_EEPROM_AT24) || defined(CONFIG_EEPROM_AT24_MODULE)
#include <linux/i2c/at24.h>
	 
static struct at24_platform_data m24c01 = {
	.byte_len       = SZ_1K / 4,
	.page_size      = 16,
};

static struct i2c_board_info __initdata am3517somiq_i2c2_boardinfo[] = {
	{
		I2C_BOARD_INFO("24c01", 0x50),
		.platform_data  = &m24c01,
	},
};
#else
static struct i2c_board_info __initdata am3517somiq_i2c2_boardinfo[] = {};
#endif

static struct regulator_consumer_supply am3517somiq_vdd1_supplies[] = {
	{
		.supply = "vdd_core",
	},
};

static struct regulator_init_data am3517somiq_regulator_vdd1 = {
	.constraints = {
		.min_uV = 1200000,
		.max_uV = 1200000,
		.valid_modes_mask = REGULATOR_MODE_NORMAL,
		.valid_ops_mask = REGULATOR_CHANGE_STATUS,
		.always_on = true,
		.apply_uV = true,
	},
	.num_consumer_supplies = ARRAY_SIZE(am3517somiq_vdd1_supplies),
	.consumer_supplies = am3517somiq_vdd1_supplies,
};

static struct regulator_consumer_supply am3517somiq_vdd2_supplies[] = {
	{
		.supply = "vddshv",
	},
};

static struct regulator_init_data am3517somiq_regulator_vdd2 = {
	.constraints = {
		.min_uV = 3300000,
		.max_uV = 3300000,
		.valid_modes_mask = REGULATOR_MODE_NORMAL,
		.valid_ops_mask = REGULATOR_CHANGE_STATUS,
		.always_on = true,
		.apply_uV = true,
	},
	.num_consumer_supplies = ARRAY_SIZE(am3517somiq_vdd2_supplies),
	.consumer_supplies = am3517somiq_vdd2_supplies,
};


static struct regulator_consumer_supply am3517somiq_vio_supplies[] = {
	{
		.supply = "vdds",
	},
};

static struct regulator_init_data am3517somiq_regulator_vio = {
	.constraints = {
		.min_uV = 1800000,
		.max_uV = 1800000,
		.valid_modes_mask = REGULATOR_MODE_NORMAL,
		.valid_ops_mask = REGULATOR_CHANGE_STATUS,
		.always_on = true,
		.apply_uV = true,
	},
	.num_consumer_supplies = ARRAY_SIZE(am3517somiq_vio_supplies),
	.consumer_supplies = am3517somiq_vio_supplies,
};


static struct regulator_consumer_supply am3517somiq_vaux1_supplies[] = {
	{
		.supply = "vdd_sram_mpu",
	},
	{
		.supply = "vdd_sram_core_bg0",
	},
	{
		.supply = "vddsosc",
	},
};

static struct regulator_init_data am3517somiq_regulator_vaux1 = {
	.constraints = {
		.min_uV = 1800000,
		.max_uV = 1800000,
		.valid_modes_mask = REGULATOR_MODE_NORMAL,
		.valid_ops_mask = REGULATOR_CHANGE_STATUS,
		.always_on = true,
		.apply_uV = true,
	},
	.num_consumer_supplies = ARRAY_SIZE(am3517somiq_vaux1_supplies),
	.consumer_supplies = am3517somiq_vaux1_supplies,
};


static struct regulator_consumer_supply am3517somiq_vaux2_supplies[] = {
	{
		.supply = "vdda1p8v_usbphy",
	},
};

static struct regulator_init_data am3517somiq_regulator_vaux2 = {
	.constraints = {
		.min_uV = 1800000,
		.max_uV = 1800000,
		.valid_modes_mask = REGULATOR_MODE_NORMAL,
		.valid_ops_mask = REGULATOR_CHANGE_STATUS,
		.always_on = true,
		.apply_uV = true,
	},
	.num_consumer_supplies = ARRAY_SIZE(am3517somiq_vaux2_supplies),
	.consumer_supplies = am3517somiq_vaux2_supplies,
};


static struct regulator_consumer_supply am3517somiq_vdac_supplies[] = {
	{
		.supply = "vdda_dac",
	},
};

static struct regulator_init_data am3517somiq_regulator_vdac = {
	.constraints = {
		.min_uV = 1800000,
		.max_uV = 1800000,
		.valid_modes_mask = REGULATOR_MODE_NORMAL,
		.valid_ops_mask = REGULATOR_CHANGE_MODE,
		.always_on = true,
		.apply_uV = true,
	},
	.num_consumer_supplies = ARRAY_SIZE(am3517somiq_vdac_supplies),
	.consumer_supplies = am3517somiq_vdac_supplies,
};

static struct regulator_consumer_supply am3517somiq_vmmc_supplies[] = {
	{
		.supply = "vdda3p3v_usbphy",
	},
};

static struct regulator_init_data am3517somiq_regulator_vmmc = {
	.constraints = {
		.min_uV = 3300000,
		.max_uV = 3300000,
		.valid_modes_mask = REGULATOR_MODE_NORMAL,
		.valid_ops_mask = REGULATOR_CHANGE_STATUS,
		.always_on = true,
		.apply_uV = true,
	},
	.num_consumer_supplies = ARRAY_SIZE(am3517somiq_vmmc_supplies),
	.consumer_supplies = am3517somiq_vmmc_supplies,
};


static struct regulator_consumer_supply am3517somiq_vpll_supplies[] = {
	{
		.supply = "vdds_dpll_mpu_usbhost",
	},
	{
		.supply = "vdds_dpll_per_core",
	},
};

static struct regulator_init_data am3517somiq_regulator_vpll = {
	.constraints = {
		.min_uV = 1800000,
		.max_uV = 1800000,
		.valid_modes_mask = REGULATOR_MODE_NORMAL,
		.valid_ops_mask = REGULATOR_CHANGE_STATUS,
		.always_on = true,
		.apply_uV = true,
	},
	.num_consumer_supplies = ARRAY_SIZE(am3517somiq_vpll_supplies),
	.consumer_supplies = am3517somiq_vpll_supplies,
};

/* Configure TPS65910 for am3517somiq board needs */
static int am3517somiq_tps65910_config(struct tps65910_platform_data *pdata)
{
	u8 val 	= 0;
	int i 	= 0;
	int err = -1;

	/* Mask ALL interrupts */
	err = tps65910_i2c_write_u8(TPS65910_I2C_ID0, 0xFF,
			TPS65910_REG_INT_MSK);
	if (err) {
		printk(KERN_ERR "Unable to write TPS65910_REG_INT_MSK reg\n");
		return -EIO;
	}
	err = tps65910_i2c_write_u8(TPS65910_I2C_ID0, 0x03,
			TPS65910_REG_INT_MSK2);
	if (err) {
		printk(KERN_ERR "Unable to write TPS65910_REG_INT_MSK2 reg\n");
		return -EIO;
	}

	/* Set RTC regulator on during sleep */

	val = 0;
	err = tps65910_i2c_write_u8(TPS65910_I2C_ID0, val,
			TPS65910_REG_VRTC);

	if (err) {
		printk(KERN_ERR "Unable to write TPS65910_REG_VRTC reg\n");
		return -EIO;
	}
	/* Set RTC Power, disable Smart Reflex in DEVCTRL_REG */
	val = 0;
	val &= ~TPS65910_RTC_PWDNN;
	val &= ~TPS65910_CK32K_CTRL; /* Enable 32k crystal oscillator */
	val |= TPS65910_SR_CTL_I2C_SEL;

	err = tps65910_i2c_write_u8(TPS65910_I2C_ID0, val,
			TPS65910_REG_DEVCTRL);
	if (err) {
		printk(KERN_ERR "Unable to write TPS65910_REG_DEVCTRL reg\n");
		return -EIO;
	}

	/* Enable and set back-up battery charger control*/

	tps65910_enable_bbch(TPS65910_BBSEL_2P52);

	/* initilize all ISR work as NULL, specific driver will
	 * assign function(s) later.
	 */
	for (i = 0; i < TPS65910_MAX_IRQS; i++)
		pdata->handlers[i] = NULL;

	return 0;
}

struct tps65910_platform_data am3517somiq_tps65910_data = {
	.irq_num 	= (unsigned)TPS65910_HOST_IRQ,
	.gpio  		= NULL,
	.vio   		= &am3517somiq_regulator_vio,
	.vdd1  		= &am3517somiq_regulator_vdd1,
	.vdd2  		= &am3517somiq_regulator_vdd2,
	.vdd3  		= NULL,
	.vdig1		= NULL,
	.vdig2		= NULL,
	.vaux33		= NULL,
	.vmmc		= &am3517somiq_regulator_vmmc,
	.vaux1		= &am3517somiq_regulator_vaux1,
	.vaux2		= &am3517somiq_regulator_vaux2,
	.vdac		= &am3517somiq_regulator_vdac,
	.vpll		= &am3517somiq_regulator_vpll,
	.board_tps65910_config = am3517somiq_tps65910_config,
};

static struct i2c_board_info __initdata am3517somiq_i2c1_boardinfo[] = {
	{
		I2C_BOARD_INFO("tps65910", TPS65910_I2C_ID0),
		.flags          = I2C_CLIENT_WAKE,
		.irq            = TPS65910_HOST_IRQ,
		.platform_data  = &am3517somiq_tps65910_data,
	},
};

static int __init am3517somiq_i2c_init(void)
{
	omap_register_i2c_bus(1, 400, am3517somiq_i2c1_boardinfo,
			ARRAY_SIZE(am3517somiq_i2c1_boardinfo));
	omap_register_i2c_bus(2, 400, am3517somiq_i2c2_boardinfo,
			ARRAY_SIZE(am3517somiq_i2c2_boardinfo));
	omap_register_i2c_bus(3, 400, NULL, 0);

	return 0;
}

#define SOMIQ_GPIO_DVI_EN (10)

static void __init am3517somiq_display_init(void)
{
        /* Configure GPIO for DVI enable */
        omap_mux_init_gpio(SOMIQ_GPIO_DVI_EN, OMAP_PIN_INPUT);
        gpio_request(SOMIQ_GPIO_DVI_EN, "DVI_nPD");
        gpio_direction_output(SOMIQ_GPIO_DVI_EN, true);
}

static int am3517somiq_panel_enable_dvi(struct omap_dss_device *dssdev)
{
	if (gpio_is_valid(SOMIQ_GPIO_DVI_EN)) 
		gpio_set_value(SOMIQ_GPIO_DVI_EN, 1);

	return 0;
}

static void am3517somiq_panel_disable_dvi(struct omap_dss_device *dssdev)
{
	if (gpio_is_valid(SOMIQ_GPIO_DVI_EN)) 
		gpio_set_value(SOMIQ_GPIO_DVI_EN, 1);
}

static int am3517somiq_panel_enable_tv(struct omap_dss_device *dssdev)
{
	return 0;
}

static void am3517somiq_panel_disable_tv(struct omap_dss_device *dssdev)
{
}

static struct omap_dss_device am3517somiq_tv_device = {
	.type 			= OMAP_DISPLAY_TYPE_VENC,
	.name 			= "tv",
	.driver_name		= "venc",
	.phy.venc.type		= OMAP_DSS_VENC_TYPE_SVIDEO,
	.platform_enable	= am3517somiq_panel_enable_tv,
	.platform_disable	= am3517somiq_panel_disable_tv,
};

static struct omap_dss_device am3517somiq_dvi_device = {
	.type			= OMAP_DISPLAY_TYPE_DPI,
	.name			= "dvi",
	.driver_name		= "generic_panel",
	.phy.dpi.data_lines	= 24,
	.platform_enable	= am3517somiq_panel_enable_dvi,
	.platform_disable	= am3517somiq_panel_disable_dvi,
};

static struct omap_dss_device *am3517somiq_dss_devices[] = {
	&am3517somiq_tv_device,
	&am3517somiq_dvi_device,
};

static struct omap_dss_board_info am3517somiq_dss_data = {
	.num_devices	= ARRAY_SIZE(am3517somiq_dss_devices),
	.devices	= am3517somiq_dss_devices,
	.default_device	= &am3517somiq_dvi_device,
};

static struct platform_device am3517somiq_dss_device = {
	.name		= "omapdss",
	.id		= -1,
	.dev		= {
		.platform_data	= &am3517somiq_dss_data,
	},
};

/*
 * Board initialization
 */
static struct omap_board_config_kernel am3517somiq_config[] __initdata = {
};

static struct platform_device *am3517somiq_devices[] __initdata = {
	&am3517somiq_dss_device,
};

static void __init am3517somiq_init_irq(void)
{
	omap_board_config = am3517somiq_config;
	omap_board_config_size = ARRAY_SIZE(am3517somiq_config);
	omap2_init_common_infrastructure();
	omap2_init_common_devices(NULL, NULL);
	omap_init_irq();
	gpmc_init();
}

static struct omap_musb_board_data musb_board_data = {
	.interface_type         = MUSB_INTERFACE_ULPI,
	.mode                   = MUSB_OTG,
	.power                  = 500,
};

static __init void am3517somiq_musb_init(void)
{
	u32 devconf2;

	/*
	 * Set up USB clock/mode in the DEVCONF2 register.
	 */
	devconf2 = omap_ctrl_readl(AM35XX_CONTROL_DEVCONF2);

	/* USB2.0 PHY reference clock is 13 MHz */
	devconf2 &= ~(CONF2_REFFREQ | CONF2_OTGMODE | CONF2_PHY_GPIOMODE);
	devconf2 |=  CONF2_REFFREQ_13MHZ | CONF2_SESENDEN | CONF2_VBDTCTEN
			| CONF2_DATPOL;

	omap_ctrl_writel(devconf2, AM35XX_CONTROL_DEVCONF2);

	usb_musb_init(&musb_board_data);
}

#define SOMIQ_GPIO_USBH_RST (186)

static const struct ehci_hcd_omap_platform_data ehci_pdata __initconst = {
	.port_mode[0] = EHCI_HCD_OMAP_MODE_PHY,
	.port_mode[1] = EHCI_HCD_OMAP_MODE_UNKNOWN,
	.port_mode[2] = EHCI_HCD_OMAP_MODE_UNKNOWN,

	.phy_reset  = true,
	.reset_gpio_port[0]  = SOMIQ_GPIO_USBH_RST,
	.reset_gpio_port[1]  = -EINVAL,
	.reset_gpio_port[2]  = -EINVAL
};

#ifdef CONFIG_OMAP_MUX
static struct omap_board_mux board_mux[] __initdata = {
	/* USB OTG DRVVBUS offset = 0x212 */
	OMAP3_MUX(SAD2D_MCAD23, OMAP_MUX_MODE0 | OMAP_PIN_INPUT_PULLDOWN),
	OMAP3_MUX(MCBSP_CLKS, OMAP_MUX_MODE4 | OMAP_PIN_INPUT_PULLUP),
	OMAP3_MUX(GPMC_NCS4, OMAP_MUX_MODE4 | OMAP_PIN_INPUT_PULLDOWN),
	OMAP3_MUX(SYS_NRESWARM, OMAP_MUX_MODE4 | OMAP_PIN_INPUT_PULLUP),
	{ .reg_offset = OMAP_MUX_TERMINATOR },
};
#endif

/*
 * HECC information
 */

static struct resource am3517_hecc_resources[] = {
	{
		.start	= AM35XX_IPSS_HECC_BASE,
		.end	= AM35XX_IPSS_HECC_BASE + 0x3FFF,
		.flags	= IORESOURCE_MEM,
	},
	{
		.start	= INT_35XX_HECC0_IRQ,
		.end	= INT_35XX_HECC0_IRQ,
		.flags	= IORESOURCE_IRQ,
	},
};

static struct platform_device am3517_hecc_device = {
	.name		= "ti_hecc",
	.id		= -1,
	.num_resources	= ARRAY_SIZE(am3517_hecc_resources),
	.resource	= am3517_hecc_resources,
};

static struct ti_hecc_platform_data am3517somiq_hecc_pdata = {
	.scc_hecc_offset	= AM35XX_HECC_SCC_HECC_OFFSET,
	.scc_ram_offset		= AM35XX_HECC_SCC_RAM_OFFSET,
	.hecc_ram_offset	= AM35XX_HECC_RAM_OFFSET,
	.mbx_offset		= AM35XX_HECC_MBOX_OFFSET,
	.int_line		= AM35XX_HECC_INT_LINE,
	.version		= AM35XX_HECC_VERSION,
};

static void am3517somiq_hecc_init(struct ti_hecc_platform_data *pdata)
{
	am3517_hecc_device.dev.platform_data = pdata;
	platform_device_register(&am3517_hecc_device);
}

static struct omap2_hsmmc_info mmc[] = {
	{
		.mmc		= 1,
		.caps		= MMC_CAP_4_BIT_DATA,
		.gpio_cd	= 29,
		.gpio_wp	= -EINVAL,
	},
	{}      /* Terminator */
};


static void __init am3517somiq_init(void)
{
	omap3_mux_init(board_mux, OMAP_PACKAGE_CBB);

	am3517somiq_i2c_init();
	platform_add_devices(am3517somiq_devices,
				ARRAY_SIZE(am3517somiq_devices));

	omap_serial_init();

	/* Configure GPIO for EHCI port */
	omap_mux_init_gpio(SOMIQ_GPIO_USBH_RST, OMAP_PIN_OUTPUT);
	usb_ehci_init(&ehci_pdata);
	am3517somiq_hecc_init(&am3517somiq_hecc_pdata);

	/* DSS */
	am3517somiq_display_init();

#ifdef CONFIG_MTD_NAND_OMAP2
	/* NAND */
	board_nand_init(am3517somiq_nand_partitions,
					ARRAY_SIZE(am3517somiq_nand_partitions), 0, NAND_BUSWIDTH_16);
#endif

	i2c_register_board_info(1, am3517somiq_i2c1_boardinfo,
				ARRAY_SIZE(am3517somiq_i2c1_boardinfo));
	/*Ethernet*/
	am3517somiq_ethernet_init(&am3517somiq_emac_pdata);

	/* MUSB */
	am3517somiq_musb_init();

	/* MMC init function */
	omap2_hsmmc_init(mmc);
}

MACHINE_START(SOMIQ_AM35, "AM3517 SomIQ-AM35")
	.boot_params	= 0x80000100,
	.map_io		= omap3_map_io,
	.reserve	= omap_reserve,
	.init_irq	= am3517somiq_init_irq,
	.init_machine	= am3517somiq_init,
	.timer		= &omap_timer,
MACHINE_END
